@@ -1,24 +1,22 @@
-import dj_email_url
 from django.conf import settings
 from django.core.mail import get_connection as _orig_get_connection
 from django.core.mail.backends.smtp import EmailBackend
+from speckenv_django import django_email_url
 
 
 __all__ = ["get_connection"]
 
 
 def parse_conf(settings):
-    kwargs = {
+    return {
         "host": settings["EMAIL_HOST"],
         "port": settings["EMAIL_PORT"],
         "username": settings["EMAIL_HOST_USER"],
         "password": settings["EMAIL_HOST_PASSWORD"],
         "use_tls": settings["EMAIL_USE_TLS"],
         "use_ssl": settings["EMAIL_USE_SSL"],
+        "timeout": settings["EMAIL_TIMEOUT"],
     }
-    if timeout := settings.get("EMAIL_TIMEOUT"):
-        kwargs["timeout"] = timeout
-    return kwargs
 
 
 class EmailHostsBackend(EmailBackend):
@@ -32,7 +30,7 @@ class EmailHostsBackend(EmailBackend):
 
 def get_connection(key):
     if dsn := settings.EMAIL_HOSTS.get(key):
-        config = dj_email_url.parse(dsn)
+        config = django_email_url(dsn)
         backend = EmailHostsBackend(**parse_conf(config))
         backend.default_from_email = config.get("DEFAULT_FROM_EMAIL", "")
         return backend
